@@ -120,9 +120,7 @@ appleEventProcessor(const AppleEvent *ae, AppleEvent *, long /*handlerRefCon*/)
 LIBAMAROK_EXPORT TDEAboutData aboutData( "amarok",
     I18N_NOOP( "Amarok" ), APP_VERSION,
     I18N_NOOP( "The audio player for TDE" ), TDEAboutData::License_GPL,
-    I18N_NOOP( "(C) 2002-2003, Mark Kretschmann\n(C) 2003-2007, The Amarok Development Squad\n(C) 2007-2011, The Trinity Desktop Project" ),
-    I18N_NOOP( "IRC:\nirc.freenode.net - #amarok, #amarok.de, #amarok.es\n\nFeedback:\namarok@kde.org\n\n(Build Date: " __DATE__ ")" ),
-             ( "http://amarok.kde.org" ) );
+    I18N_NOOP( "(C) 2002-2003, Mark Kretschmann\n(C) 2003-2007, The Amarok Development Squad\n(C) 2007-2011, The Trinity Desktop Project" ));
 
 App::App()
         : TDEApplication(TDEApplication::openX11RGBADisplay())
@@ -563,8 +561,7 @@ void App::showHyperThreadingWarning() // SLOT
               "configuration.</p>"
               "<p>If your system has hyperthreading, you can improve Amarok's stability by using the Linux kernel option 'NOHT', "
               "or by disabling <i>HyperThreading</i> in your BIOS setup.</p>"
-              "<p>More information can be found in the README file. For further assistance "
-              "join us at #amarok on irc.freenode.net.</p>" );
+              "<p>More information can be found in the README file.</p>" );
 
     KMessageBox::information( 0, text, i18n( "Warning" ), "showHyperThreadingWarning" );
 }
