@@ -37,16 +37,16 @@ AMAROK_EXPORT_PLUGIN( NjbMediaDevice )
 
 
 // KDE
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>       //smallIcon
 #include <kinstance.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <ktempdir.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbarbutton.h>
 #include <kurl.h>
 #include <kurlrequester.h>     //downloadSelectedItems()
 #include <kurlrequesterdlg.h>  //downloadSelectedItems()
@@ -65,7 +65,7 @@ AMAROK_EXPORT_PLUGIN( NjbMediaDevice )
 #include <time.h>
 #include <unistd.h>
 
-namespace Amarok { extern KConfig *config( const TQString& ); }
+namespace Amarok { extern TDEConfig *config( const TQString& ); }
 njb_t *NjbMediaDevice::m_njb = 0;
 // This function has NOT handled the request, so other functions may be called
 // upon to do so
@@ -86,7 +86,7 @@ NjbMediaDevice::NjbMediaDevice(): MediaDevice()
     m_customButton = true;
     m_td = 0;
     NJB_Set_Debug(0); // or try DD_SUBTRACE
-    KToolBarButton* customButton = MediaBrowser::instance()->getToolBar()->getButton( MediaBrowser::CUSTOM );
+    TDEToolBarButton* customButton = MediaBrowser::instance()->getToolBar()->getButton( MediaBrowser::CUSTOM );
     customButton->setText( i18n("Special device functions") );
     TQToolTip::remove( customButton );
     TQToolTip::add( customButton, i18n( "Special functions of your jukebox" ) );
@@ -133,7 +133,7 @@ NjbMediaDevice::unlockDevice()
 }
 
 bool
-NjbMediaDevice::getCapacity(KIO::filesize_t* total, KIO::filesize_t* available)
+NjbMediaDevice::getCapacity(TDEIO::filesize_t* total, TDEIO::filesize_t* available)
 {
     if(!m_connected)
 	return false;
@@ -635,7 +635,7 @@ NjbMediaDevice::rmbPressed(TQListViewItem* qitem, const TQPoint& point, int )
     NjbMediaItem *item = static_cast<NjbMediaItem *>(qitem);
     if ( item )
     {
-        KPopupMenu menu( m_view);
+        TDEPopupMenu menu( m_view);
         menu.insertItem( SmallIconSet( Amarok::icon( "collection" ) ), i18n("Download file"), DOWNLOAD );
         menu.insertItem( SmallIconSet( Amarok::icon( "collection" ) ), i18n("Download to collection"), DOWNLOAD_TO_COLLECTION );
         menu.insertSeparator();
